RootSplashState class
- Inheritance
-
- Object
- ChangeNotifier
- RootState
- RootSplashState
Constructors
Properties
- animateSplash → bool
-
no setter
-
bootstrap
→ Future<
void> -
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- isBusy → bool
-
no setterinherited
- isModalBackdrop → bool
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showSplash → bool
-
no setter
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
dispose(
) → void -
Discards any resources used by the object.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notify(
) → void -
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
resetBusy(
) → void -
inherited
-
resetModalBackdrop(
) → void -
inherited
-
setBusy(
[dynamic value = true]) → void -
inherited
-
setModalBackdrop(
) → void -
inherited
-
setShowSplash(
bool show) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited