SplitViewFolderTab class

Inheritance
  • Object
  • FolderTab
  • SplitViewFolderTab

Constructors

SplitViewFolderTab({required String hookName, required String title, Widget? icon, IconData? iconData, void onInitTabController(TabController)?, bool isTabVisible(BuildContext)?, void onTabVisible(BuildContext)?, void onTabHidden(BuildContext)?, required Widget content, int order = 0})
const

Properties

color → Color?
finalinherited
content → Widget?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
hookName → String
no setteroverride
icon → Widget?
finalinherited
iconData → IconData?
finalinherited
labelColor → Color?
finalinherited
labelStyle → TextStyle?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spaceBetween → double
finalinherited
title → String
finalinherited
unselectedColor → Color?
finalinherited
unselectedLabelColor → Color?
finalinherited
unselectedLabelStyle → TextStyle?
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited